=== modified file 'plugin/syslog/wrap.cc'
--- plugin/syslog/wrap.cc	2010-06-24 03:15:21 +0000
+++ plugin/syslog/wrap.cc	2010-10-12 21:26:12 +0000
@@ -38,13 +38,12 @@
 WrapSyslog::~WrapSyslog ()
 {
   ::closelog();
-  delete &(WrapSyslog::singleton());
 }
 
 WrapSyslog& WrapSyslog::singleton()
 {
-  static WrapSyslog *handle = new WrapSyslog();
-  return *handle;
+  static WrapSyslog handle;
+  return handle;
 }
 
 /* TODO, for the sake of performance, scan through all the priority

=== modified file 'plugin/transaction_log/module.cc'
--- plugin/transaction_log/module.cc	2010-08-30 23:46:45 +0000
+++ plugin/transaction_log/module.cc	2010-10-12 21:15:46 +0000
@@ -53,22 +53,24 @@
 using namespace std;
 using namespace drizzled;
 
+/**
+ * The name of the main transaction log file on disk.  With no prefix,
+ * this goes into Drizzle's $datadir.
+ */
+static const char DEFAULT_LOG_FILE_PATH[]= "transaction.log"; /* In datadir... */
 /** 
  * Transaction Log plugin system variable - Is the log enabled? Only used on init().  
  */
 static bool sysvar_transaction_log_enabled= false;
+
 /** Transaction Log plugin system variable - The path to the log file used */
-static char* sysvar_transaction_log_file= NULL;
+static char* sysvar_transaction_log_file= (char *)DEFAULT_LOG_FILE_PATH;
+
 /** 
  * Transaction Log plugin system variable - A debugging variable to assist 
  * in truncating the log file. 
  */
 static bool sysvar_transaction_log_truncate_debug= false;
-/**
- * The name of the main transaction log file on disk.  With no prefix,
- * this goes into Drizzle's $datadir.
- */
-static const char DEFAULT_LOG_FILE_PATH[]= "transaction.log"; /* In datadir... */
 /** 
  * Transaction Log plugin system variable - Should we write a CRC32 checksum for 
  * each written Transaction message?
@@ -92,8 +94,8 @@
  * Transaction Log plugin system variable - The name of the replicator plugin
  * to pair the transaction log's applier with.  Defaults to "default"
  */
-static char *sysvar_transaction_log_use_replicator= NULL;
 static const char DEFAULT_USE_REPLICATOR[]= "default";
+static char *sysvar_transaction_log_use_replicator= (char *)DEFAULT_USE_REPLICATOR;
 
 /** DATA_DICTIONARY views */
 static TransactionLogTool *transaction_log_tool;
@@ -146,29 +148,27 @@
     }
   }
 
-  if (vm.count("file"))
-  {
-    sysvar_transaction_log_file= strdup(vm["file"].as<string>().c_str());
-  }
-
-  else
-  {
-    sysvar_transaction_log_file= strdup(DEFAULT_LOG_FILE_PATH);
-  }
-
-  if (vm.count("use-replicator"))
-  {
-    sysvar_transaction_log_use_replicator= strdup(vm["use-replicator"].as<string>().c_str());
-  }
-
-  else
-  {
-    sysvar_transaction_log_use_replicator= strdup(DEFAULT_USE_REPLICATOR);
-  }
 
   /* Create and initialize the transaction log itself */
   if (sysvar_transaction_log_enabled)
   {
+    if (vm.count("file"))
+    {
+      sysvar_transaction_log_file= strdup(vm["file"].as<string>().c_str());
+    }
+    else
+    {
+      sysvar_transaction_log_file= strdup(DEFAULT_LOG_FILE_PATH);
+    }
+  
+    if (vm.count("use-replicator"))
+    {
+      sysvar_transaction_log_use_replicator= strdup(vm["use-replicator"].as<string>().c_str());
+    }
+    else
+    {
+      sysvar_transaction_log_use_replicator= strdup(DEFAULT_USE_REPLICATOR);
+    }
     transaction_log= new (nothrow) TransactionLog(string(sysvar_transaction_log_file),
                                                   sysvar_transaction_log_flush_frequency,
                                                   sysvar_transaction_log_checksum_enabled);

